@@ -10,25 +10,25 @@ import select
 def parse_event_mask(events):
 	if events == 0:
 		return 'None'
-	if events == alsamixer.EventMaskRemove:
+	if events == alsamixer.event_mask_remove:
 		return 'Removed'
 	s = ''
-	for i in alsamixer.EventMask.keys():
-		if events & alsamixer.EventMask[i]:
+	for i in alsamixer.event_mask.keys():
+		if events & alsamixer.event_mask[i]:
 			s += '%s ' % i
 	return s[:-1]
 
 def event_callback(element, events):
 
 	print 'CALLBACK (DEF)! [%s] %s:%i' % (parse_event_mask(events), element.name, element.index)
-	print '  ', element.getVolumeTuple(), element.getSwitchTuple()
+	print '  ', element.get_volume_tuple(), element.get_switch_tuple()
 
 
 class MyElementEvent:
 
 	def callback(self, element, events):
 		print 'CALLBACK (CLASS)! [%s] %s:%i' % (parse_event_mask(events), element.name, element.index)
-		print '  ', element.getVolumeTuple(), element.getSwitchTuple()
+		print '  ', element.get_volume_tuple(), element.get_switch_tuple()
 
 
 mixer = alsamixer.Mixer()
@@ -36,13 +36,13 @@ mixer.attach()
 mixer.load()
 
 element1 = alsamixer.Element(mixer, "Front")
-element1.setCallback(event_callback)
+element1.set_callback(event_callback)
 element2 = alsamixer.Element(mixer, "PCM")
-element2.setCallback(MyElementEvent())
+element2.set_callback(MyElementEvent())
 
 poller = select.poll()
-mixer.registerPoll(poller)
+mixer.register_poll(poller)
 while True:
 	poller.poll()
 	print 'Poll OK!'
-	mixer.handleEvents()
+	mixer.handle_events()
